# widowx_env

widowx_env is a series of OpenAI Gym reinforcement learning environments. 
It simulates a robotic arm (WidowX MK-II) with the Pybullet engine. The goal is to bring the end-effector as close as possible to the target position (represented as a green sphere).


# Installation
 
## Pip installation

```bash
pip install widowx-env
```

## Development installation

```bash
git clone https://github.com/PierreExeter/widowx_env
cd widowx_env
pip install --e .
```